# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _Management(_AWS):
    _type = "management"
    _icon_dir = "resources/aws/management"


class AutoScaling(_Management):
    _icon = "auto-scaling.png"


class Cloudformation(_Management):
    _icon = "cloudformation.png"


class Cloudtrail(_Management):
    _icon = "cloudtrail.png"


class Cloudwatch(_Management):
    _icon = "cloudwatch.png"


class Codeguru(_Management):
    _icon = "codeguru.png"


class CommandLineInterface(_Management):
    _icon = "command-line-interface.png"


class Config(_Management):
    _icon = "config.png"


class ControlTower(_Management):
    _icon = "control-tower.png"


class LicenseManager(_Management):
    _icon = "license-manager.png"


class ManagedServices(_Management):
    _icon = "managed-services.png"


class ManagementConsole(_Management):
    _icon = "management-console.png"


class Opsworks(_Management):
    _icon = "opsworks.png"


class Organizations(_Management):
    _icon = "organizations.png"


class ServiceCatalog(_Management):
    _icon = "service-catalog.png"


class SystemsManagerParameterStore(_Management):
    _icon = "systems-manager-parameter-store.png"


class SystemsManager(_Management):
    _icon = "systems-manager.png"


class TrustedAdvisor(_Management):
    _icon = "trusted-advisor.png"


class WellArchitectedTool(_Management):
    _icon = "well-architected-tool.png"


# Aliases

SSM = SystemsManager
ParameterStore = SystemsManagerParameterStore



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Logging(_OnPrem):
    _type = "logging"
    _icon_dir = "resources/onprem/logging"


class Fluentd(_Logging):
    _icon = "fluentd.png"


class Logstash(_Logging):
    _icon = "logstash.png"


# Aliases

LogStash = Logstash



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Network(_OCI):
    _type = "network"
    _icon_dir = "resources/oci/network"


class DrgGrey(_Network):
    _icon = "drg-grey.png"


class Drg(_Network):
    _icon = "drg.png"


class FirewallGrey(_Network):
    _icon = "firewall-grey.png"


class Firewall(_Network):
    _icon = "firewall.png"


class InternetgatewayGrey(_Network):
    _icon = "internetgateway-grey.png"


class Internetgateway(_Network):
    _icon = "internetgateway.png"


class LoadbalanceGrey(_Network):
    _icon = "loadbalance-grey.png"


class Loadbalance(_Network):
    _icon = "loadbalance.png"


class RoutetableGrey(_Network):
    _icon = "routetable-grey.png"


class Routetable(_Network):
    _icon = "routetable.png"


class SecuritylistsGrey(_Network):
    _icon = "securitylists-grey.png"


class Securitylists(_Network):
    _icon = "securitylists.png"


class ServiceGatewayGrey(_Network):
    _icon = "service-gateway-grey.png"


class ServiceGateway(_Network):
    _icon = "service-gateway.png"


class VcloudnetworkGrey(_Network):
    _icon = "vcloudnetwork-grey.png"


class Vcloudnetwork(_Network):
    _icon = "vcloudnetwork.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Security(_OCI):
    _type = "security"
    _icon_dir = "resources/oci/security"


class AuditGrey(_Security):
    _icon = "audit-grey.png"


class Audit(_Security):
    _icon = "audit.png"


class CompartmentsGrey(_Security):
    _icon = "compartments-grey.png"


class Compartments(_Security):
    _icon = "compartments.png"


class DdosGrey(_Security):
    _icon = "ddos-grey.png"


class Ddos(_Security):
    _icon = "ddos.png"


class EncryptionGrey(_Security):
    _icon = "encryption-grey.png"


class Encryption(_Security):
    _icon = "encryption.png"


class GroupsGrey(_Security):
    _icon = "groups-grey.png"


class Groups(_Security):
    _icon = "groups.png"


class IdAccessGrey(_Security):
    _icon = "id-access-grey.png"


class IdAccess(_Security):
    _icon = "id-access.png"


class KeymgmtGrey(_Security):
    _icon = "keymgmt-grey.png"


class Keymgmt(_Security):
    _icon = "keymgmt.png"


class OcidGrey(_Security):
    _icon = "ocid-grey.png"


class Ocid(_Security):
    _icon = "ocid.png"


class PoliciesGrey(_Security):
    _icon = "policies-grey.png"


class Policies(_Security):
    _icon = "policies.png"


class TaggingGrey(_Security):
    _icon = "tagging-grey.png"


class Tagging(_Security):
    _icon = "tagging.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Network(_OnPrem):
    _type = "network"
    _icon_dir = "resources/onprem/network"


class Apache(_Network):
    _icon = "apache.png"


class Caddy(_Network):
    _icon = "caddy.png"


class Consul(_Network):
    _icon = "consul.png"


class Envoy(_Network):
    _icon = "envoy.png"


class Etcd(_Network):
    _icon = "etcd.png"


class Haproxy(_Network):
    _icon = "haproxy.png"


class Internet(_Network):
    _icon = "internet.png"


class Istio(_Network):
    _icon = "istio.png"


class Kong(_Network):
    _icon = "kong.png"


class Linkerd(_Network):
    _icon = "linkerd.png"


class Nginx(_Network):
    _icon = "nginx.png"


class Pfsense(_Network):
    _icon = "pfsense.png"


class Pomerium(_Network):
    _icon = "pomerium.png"


class Tomcat(_Network):
    _icon = "tomcat.png"


class Traefik(_Network):
    _icon = "traefik.png"


class Vyos(_Network):
    _icon = "vyos.png"


class Zookeeper(_Network):
    _icon = "zookeeper.png"


# Aliases

ETCD = Etcd
HAProxy = Haproxy
PFSense = Pfsense
VyOS = Vyos



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Storage(_OCI):
    _type = "storage"
    _icon_dir = "resources/oci/storage"


class BackuprestoreGrey(_Storage):
    _icon = "backuprestore-grey.png"


class Backuprestore(_Storage):
    _icon = "backuprestore.png"


class BlockstorageGrey(_Storage):
    _icon = "blockstorage-grey.png"


class Blockstorage(_Storage):
    _icon = "blockstorage.png"


class BucketsGrey(_Storage):
    _icon = "buckets-grey.png"


class Buckets(_Storage):
    _icon = "buckets.png"


class DatatransferGrey(_Storage):
    _icon = "datatransfer-grey.png"


class Datatransfer(_Storage):
    _icon = "datatransfer.png"


class FilestorageGrey(_Storage):
    _icon = "filestorage-grey.png"


class Filestorage(_Storage):
    _icon = "filestorage.png"


class ObjectstorageGrey(_Storage):
    _icon = "objectstorage-grey.png"


class Objectstorage(_Storage):
    _icon = "objectstorage.png"


class StoragegatewayGrey(_Storage):
    _icon = "storagegateway-grey.png"


class Storagegateway(_Storage):
    _icon = "storagegateway.png"


# Aliases
